==> haskell-barbies-2.1.1.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-DognSI4biYXIee7wqijCSO
key:                  barbies-2.1.1.0-DognSI4biYXIee7wqijCSO
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  1379f9ae52db5416e6235487222d0531
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-DognSI4biYXIee7wqijCSO
depends:
    base-4.17.2.1 distributive-0.6.2.1-9qCLvloqEcZBWquZrvIl0c
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-barbies-2.1.1.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-L9JjSQWxOwyLIfjokqvGtq
key:                  barbies-2.1.1.0-L9JjSQWxOwyLIfjokqvGtq
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  ea2f7cedf1a49b051c9e8495938dcc1d
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-L9JjSQWxOwyLIfjokqvGtq
depends:
    base-4.17.2.1 distributive-0.6.2.1-CfqG4Qshzh36Be0egKSxXZ
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
